"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("./helpers");
/**
 * Inverts previous value.
 *
 * Previous value must be boolean.
 *
 * ```
 * pipe(useCallValue()).pipe(inverse()).resolveSync(true) // false
 * pipe(useCallValue()).pipe(inverse()).resolveSync(false) // true
 * ```
 * @export
 * @returns {ExplicitCallable<boolean, boolean>}
 */
function inverse() {
    return function (arg) {
        helpers_1.throwIfNotBoolean('inverse', arg);
        return !arg;
    };
}
exports.inverse = inverse;
/**
 * Puts a `false` value.
 *
 * ```
 * pipe(F()).resolveSync(undefined) // false
 * ```
 * @export
 * @returns {ExplicitCallable<unknown, false>}
 */
function F() {
    return function () { return false; };
}
exports.F = F;
/**
 * Puts a `true` value.
 *
 * ```
 * pipe(T()).resolveSync(undefined) // true
 * ```
 * @export
 * @returns {ExplicitCallable<unknown, true>}
 */
function T() {
    return function () { return true; };
}
exports.T = T;
